@@ -11,7 +11,7 @@ class SDK:
             self._sdk = MercadoPagoSDK(merchant, marketplace=marketplace)
         elif processor == 'decidir':
             self.processor = 'decidir'
-            self._sdk = DecidirSDK(merchant, merchant_cadena)
+            self._sdk = DecidirSDK(merchant, merchant_cadena, marketplace=marketplace)
 
     def customer(self):
         return self._sdk.customer()
